==> tuain-ecosystem-lib-0.1.4.tgz: package/config/db-queries/common.js <==
const mongodb = require('mongodb');

const { ObjectId } = mongodb;

function findByName(name) {
  return { name };
}

function findById(id) {
  return { _id: ObjectId(id) };
}

function findByAttributes(objConstraints, searchFields) {
  let findQuery = {};
  /**
     * recordsNumber, pageNumber, includeTotalRows
     * ordering: [field, order]
     * simpleFilter: ['', '']
     * filtersByValue:[{ field, operator, value}]
     */
  if (objConstraints && objConstraints.simpleFilter) {
    const textToFind = objConstraints.simpleFilter[0];
    const queryRestrictions = [];
    searchFields.forEach((searchField) => {
      const fieldQuery = {};
      fieldQuery[searchField] = { $regex: textToFind };
      queryRestrictions.push(fieldQuery);
    });
    findQuery = { $or: queryRestrictions };
  } else if (objConstraints && objConstraints.filtersByValue) {
    objConstraints.filtersByValue.forEach((fieldFilter) => {
      const { field, operator, value } = fieldFilter;
      if (searchFields.includes(field)) {
        if (operator === '==') {
          findQuery[field] = value;
        }
      }
    });
  }
  return findQuery;
}

function updateObj(appData) {
  return { $set: { ...appData } };
}

function addExternalRef(objectData) {
  return { $push: { externalCoding: { ...objectData } } };
}

function removeExternalRef(externalSource) {
  return { $pull: { externalCoding: { externalSource } } };
}

module.exports = {
  findByName,
  findById,
  updateObj,
  findByAttributes,
  addExternalRef,
  removeExternalRef,
};

==> tuain-ecosystem-lib-0.1.7.tgz: package/config/db-queries/common.js <==
const mongodb = require('mongodb');

const { ObjectId } = mongodb;

function findByName(name) {
  return { name };
}

function findById(id) {
  return { _id: ObjectId(id) };
}

function findByAttributes(objConstraints, searchFields) {
  let findQuery = {};
  /**
     * recordsNumber, pageNumber, includeTotalRows
     * ordering: [field, order]
     * simpleFilter: ['', '']
     * filtersByValue:[{ field, operator, value}]
     */
  if (objConstraints && objConstraints.simpleFilter) {
    const textToFind = objConstraints.simpleFilter[0];
    const queryRestrictions = [];
    searchFields.forEach((searchField) => {
      const fieldQuery = {};
      fieldQuery[searchField] = { $regex: textToFind };
      queryRestrictions.push(fieldQuery);
    });
    findQuery = { $or: queryRestrictions };
  } else if (objConstraints && objConstraints.filtersByValue) {
    objConstraints.filtersByValue.forEach((fieldFilter) => {
      const { field, operator, value } = fieldFilter;
      if (searchFields.includes(field)) {
        if (operator === '==') {
          findQuery[field] = value;
        }
      }
    });
  }
  return findQuery;
}

function updateObj(appData) {
  const querySet = { ...appData };
  if (querySet.additionaData) {
    Object.entries(querySet.additionaData).forEach(([key, val]) => {
      querySet[`additionaData.${key}`] = val;
    });
    delete querySet.additionaData;
  }
  return { $set: { ...querySet } };
}

function addExternalRef(objectData) {
  return { $push: { externalCoding: { ...objectData } } };
}

function removeExternalRef(externalSource) {
  return { $pull: { externalCoding: { externalSource } } };
}

module.exports = {
  findByName,
  findById,
  updateObj,
  findByAttributes,
  addExternalRef,
  removeExternalRef,
};
